+++
title = "Remove a front-matter key"
description = """
  This test removes the `foo` front-matter key from the exported file
  (and replaces `bar` key with `zoo`).
  """
tags = ["front-matter", "keys", "replace", "remove"]
draft = false
zoo = 2
+++
